@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -206,19 +206,21 @@ dbus_data_create (TrackerMiner          *miner,
 
 	/* Now we're successfully connected and registered, create the data */
 	data = g_slice_new0 (DBusData);
+	/* Connection object is a shared one, so we need to keep our own
+	 * reference to it */
 	data->connection = dbus_g_connection_ref (connection);
-	data->gproxy = g_object_ref (gproxy);
-        data->name_monitors = g_hash_table_new_full (g_str_hash,
-                                                     g_str_equal,
-                                                     (GDestroyNotify) g_free,
-                                                     NULL);
+	data->gproxy = gproxy;
+	data->name_monitors = g_hash_table_new_full (g_str_hash,
+	                                             g_str_equal,
+	                                             (GDestroyNotify) g_free,
+	                                             NULL);
 
 	return data;
 }
 
 void
-tracker_miner_dbus_init (TrackerMiner          *miner,
-                         const DBusGObjectInfo *info)
+_tracker_miner_dbus_init (TrackerMiner          *miner,
+                          const DBusGObjectInfo *info)
 {
 	DBusData *data;
         gchar *name;
@@ -261,7 +263,7 @@ tracker_miner_dbus_init (TrackerMiner          *miner,
 }
 
 void
-tracker_miner_dbus_shutdown (TrackerMiner *miner)
+_tracker_miner_dbus_shutdown (TrackerMiner *miner)
 {
 	g_return_if_fail (TRACKER_IS_MINER (miner));
 
@@ -273,9 +275,9 @@ tracker_miner_dbus_shutdown (TrackerMiner *miner)
 }
 
 void
-tracker_miner_dbus_add_name_watch (TrackerMiner             *miner,
-                                   const gchar              *name,
-                                   TrackerMinerDBusNameFunc  func)
+_tracker_miner_dbus_add_name_watch (TrackerMiner             *miner,
+                                    const gchar              *name,
+                                    TrackerMinerDBusNameFunc  func)
 {
         DBusData *data;
 
