@@ -774,7 +774,7 @@ get_mount_point_by_uuid_foreach (gpointer key,
 
 	/* is mount of the type we're looking for? */
 	if ((gr->exact_match && mount_type == gr->type) ||
-	    (!gr->exact_match && ((mount_type & gr->type) == gr->type))) {
+	    (!gr->exact_match && (mount_type & gr->type))) {
 		gchar *normalized_mount_point;
 		gint len;
 
@@ -865,7 +865,7 @@ tracker_storage_get_device_uuids (TrackerStorage     *storage,
 
 		/* is mount of the type we're looking for? */
 		if ((exact_match && mount_type == type) ||
-		    (!exact_match && ((mount_type & type) == type))) {
+		    (!exact_match && (mount_type & type))) {
 			uuids = g_slist_prepend (uuids, g_strdup (uuid));
 		}
 	}
@@ -904,6 +904,44 @@ tracker_storage_get_mount_point_for_uuid (TrackerStorage *storage,
 	return info->mount_point;
 }
 
+/**
+ * tracker_storage_get_type_for_uuid:
+ * @storage: A #TrackerStorage
+ * @uuid: A string pointer to the UUID for the %GVolume.
+ *
+ * Returns: The type flags for @uuid.
+ **/
+TrackerStorageType
+tracker_storage_get_type_for_uuid (TrackerStorage     *storage,
+                                   const gchar        *uuid)
+{
+	TrackerStoragePrivate *priv;
+	GNode *node;
+	TrackerStorageType type = 0;
+
+	g_return_val_if_fail (TRACKER_IS_STORAGE (storage), 0);
+	g_return_val_if_fail (uuid != NULL, 0);
+
+	priv = TRACKER_STORAGE_GET_PRIVATE (storage);
+
+	node = g_hash_table_lookup (priv->mounts_by_uuid, uuid);
+
+	if (node) {
+		MountInfo *info;
+
+		info = node->data;
+
+		if (info->removable) {
+			type |= TRACKER_STORAGE_REMOVABLE;
+		}
+		if (info->optical) {
+			type |= TRACKER_STORAGE_OPTICAL;
+		}
+	}
+
+	return type;
+}
+
 /**
  * tracker_storage_get_uuid_for_file:
  * @storage: A #TrackerStorage
